<?php

namespace Drupal\cforge\Access;

use Drupal\user\Entity\User;
use Drupal\Core\Access\AccessResult;
use Drupal\Core\Routing\Access\AccessInterface;
use Drupal\Core\Session\AccountInterface;
use Symfony\Component\Routing\Route;

/**
 * Determines access to routes based on login status of current user.
 */
class NotNominatedReferrerCheck implements AccessInterface {

  const TIME_LIMIT = '1 month';

  /**
   * Grants access to users less than a month old who have not yet nominated a referrer.
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   The currently logged in account.
   * @param \Symfony\Component\Routing\Route $route
   *   The route to check against.
   *
   * @return \Drupal\Core\Access\AccessResultInterface
   *   The access result.
   */
  public function access(AccountInterface $account, Route $route) {
    $user = User::load($account->id());
    if ($user->getCreatedTime() > strtotime('-'.SELF::TIME_LIMIT)) {
      $access_result = AccessResult::forbidden('User is older than '.SELF::TIME_LIMIT);
    }
    elseif (\Drupal::keyValue('user_referrer')->has($account->id())) {
      $access_result = AccessResult::forbidden('Referral fee already paid for user '.$user->getDisplayName());
    }
    else {
      $access_result = AccessResult::allowed();
    }
    return $access_result->cachePerUser();
  }

}
